@@ -1,7 +1,9 @@
 package DBIx::OnlineDDL::Helper::SQLite;
 
 our $AUTHORITY = 'cpan:GSG';
-our $VERSION   = '0.92';
+# ABSTRACT: Private OnlineDDL helper for SQLite-specific code
+use version;
+our $VERSION = 'v1.0.0'; # VERSION
 
 use v5.10;
 use Moo;
@@ -10,31 +12,22 @@ extends 'DBIx::OnlineDDL::Helper::Base';
 
 use Types::Standard qw( InstanceOf );
 
-use DBI::Const::GetInfoType;
 use Sub::Util qw( set_subname );
 
 use namespace::clean;  # don't export the above
 
-=encoding utf8
-
-=head1 NAME
-
-DBIx::OnlineDDL::Helper::SQLite - Private OnlineDDL helper for SQLite-specific code
-
-=head1 VERSION
-
-version 0.92
-
-=head1 DESCRIPTION
-
-This is a private helper module for any SQLite-specific code.  B<As a private module, any
-methods or attributes here are subject to change.>
-
-You should really be reading documentation for L<DBIx::OnlineDDL>.  Or, if you want to
-create a helper module for a different RDBMS, read the docs for
-L<DBIx::OnlineDDL::Helper::Base>.
-
-=cut
+#pod =encoding utf8
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This is a private helper module for any SQLite-specific code.  B<As a private module, any
+#pod methods or attributes here are subject to change.>
+#pod
+#pod You should really be reading documentation for L<DBIx::OnlineDDL>.  Or, if you want to
+#pod create a helper module for a different RDBMS, read the docs for
+#pod L<DBIx::OnlineDDL::Helper::Base>.
+#pod
+#pod =cut
 
 sub dbms_uses_global_fk_namespace { 0 }
 sub child_fks_need_adjusting      { 0 }
@@ -89,9 +82,7 @@ sub post_connection_stmts {
     # Also, while this change was introduced in 3.25.0, it seems to only manifest itself
     # when the driver reports version 3.26.0, possibly due to how their production
     # releases work.
-    no warnings 'numeric';
-    my $db_ver = $self->dbh->get_info( $GetInfoType{SQL_DBMS_VER} ) || 0;
-    push @stmts, 'PRAGMA legacy_alter_table = ON' if $db_ver+0 >= 3.26;
+    push @stmts, 'PRAGMA legacy_alter_table = ON' if $self->mmver >= 3.026;
 
     return @stmts;
 }
@@ -127,7 +118,7 @@ sub create_table_sql {
 
 # Keep Base->rename_fks_in_table_sql (not used)
 
-sub has_triggers_on_table {
+sub has_conflicting_triggers_on_table {
     my ($self, $table_name) = @_;
 
     return $self->dbh_runner(run => set_subname '_has_triggers_on_table', sub {
@@ -163,20 +154,41 @@ sub analyze_table {
 
 # Keep the other FK methods (not used)
 
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+DBIx::OnlineDDL::Helper::SQLite - Private OnlineDDL helper for SQLite-specific code
+
+=head1 VERSION
+
+version v1.0.0
+
+=head1 DESCRIPTION
+
+This is a private helper module for any SQLite-specific code.  B<As a private module, any
+methods or attributes here are subject to change.>
+
+You should really be reading documentation for L<DBIx::OnlineDDL>.  Or, if you want to
+create a helper module for a different RDBMS, read the docs for
+L<DBIx::OnlineDDL::Helper::Base>.
+
 =head1 AUTHOR
 
 Grant Street Group <developers@grantstreet.com>
 
-=head1 LICENSE AND COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2019 Grant Street Group
+This software is Copyright (c) 2018 - 2022 by Grant Street Group.
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of the the Artistic License (2.0). You may obtain a
-copy of the full license at:
+This is free software, licensed under:
 
-L<http://www.perlfoundation.org/artistic_license_2_0>
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-1;
