@@ -16,7 +16,7 @@ use CDTest;
 use Import::Into;
 use Path::Class 'file';
 
-use Env qw< ONLINEDDL_TEST_DEBUG CDTEST_MASS_POPULATE CDTEST_DSN CDTEST_DBUSER CDTEST_DBPASS >;
+use Env qw< ONLINEDDL_TEST_DEBUG ONLINEDDL_NO_ACTIVITY_TEST CDTEST_MASS_POPULATE CDTEST_DSN CDTEST_DBUSER CDTEST_DBPASS >;
 
 use parent 'Exporter';
 
@@ -61,7 +61,9 @@ sub import {
         CDTest
     >;
 
-    Env->import::into($target, qw< ONLINEDDL_TEST_DEBUG CDTEST_MASS_POPULATE CDTEST_DSN CDTEST_DBUSER CDTEST_DBPASS >);
+    Env->import::into($target, qw<
+        ONLINEDDL_TEST_DEBUG ONLINEDDL_NO_ACTIVITY_TEST CDTEST_MASS_POPULATE CDTEST_DSN CDTEST_DBUSER CDTEST_DBPASS
+    >);
 
     $class->export_to_level(1, @EXPORT);
 }
@@ -71,7 +73,12 @@ sub onlineddl_test ($$&) {
     subtest("$source_name: $test_name", sub {
         # Initialize the schema
         my $cd_schema;
-        try_ok { $cd_schema = CDTest->init_schema } 'Tables created';
+        try_ok {
+            $cd_schema = CDTest->init_schema(
+               # If this is MySQL, this will test the ANSI_QUOTES flag
+               $CDTEST_DSN && $CDTEST_DSN =~ /^dbi:mysql:/ ? (on_connect_call => 'set_strict_mode') : ()
+            );
+        } 'Tables created';
         die 'Schema initialization failed!' if $@;
 
         my $rsrc = $cd_schema->source($source_name);
@@ -210,6 +217,8 @@ sub onlineddl_test ($$&) {
             $dc_count++;
             unless ($method =~ /(?:BUILD|post_connection_stmts|_build_helper|current_catalog_schema)$/ || $dc_count % 3) {
                 if ($dbms_name eq 'MySQL') {
+                    # XXX: For reasons unknown, this breaks the ANSI quote testing, so this KILL
+                    # needs to be disabled to properly test that.
                     eval { $dbh->do('KILL CONNECTION CONNECTION_ID()') };
                 }
                 else {
@@ -223,7 +232,7 @@ sub onlineddl_test ($$&) {
         # best simulate real-time usage of the table.
         no warnings 'redefine';
         my $orig_dbh_sub = \&DBIx::OnlineDDL::dbh;
-        local *DBIx::OnlineDDL::dbh = sub {
+        local *DBIx::OnlineDDL::dbh = $ONLINEDDL_NO_ACTIVITY_TEST ? $orig_dbh_sub : sub {
             my $dbh = $orig_dbh_sub->(@_);
             return $dbh unless $dbh;
             my $oddl = shift;
